bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 11. Aventiure
___________________________________________________ #### Aventivre wie sifrit sin wip heim ze lande fvrte #### vnd wie er sit da heime brvotten
###### 690 | ### Do di geste waren | alle dan gevarn ### do sprach ce sinem gesinde | sigemvndes barn ### wir svln vns ovch bereiten | haeim in miniv lant ### liep was ez sinem wibe | do ez div vrowe reht ervant
###### 691 | ### si sprach zv zir manne | wenne svl wir varn ### daz ich so harte gahe | daz heiz ich wol bewarn ### mir svln e mine brveder | teilen mir div lant ### leit was ez sifride | do erz an criemhild ervant
###### 692 | ### di fvrsten zv zim giengen | vnt sprachen alle dri ### nv wizet daz her sifrit | daz iv immer si ### mit triwen vnser dienest | bereit reht vnz an den tot ### do neig er den daegenen | do man imz so gvtlich erbot
###### 693 | ### wir svln ovch mit iv teilen | sprach giselher daz chint ### lant vnt bvrge | di vnser eigen sint ### vnd swaz der witen riche | ist vns vndertan ### der svlt ir teil vil gvten | mitsamt criemhilde han
###### 694 | ### svn der sigemvndes | zv den fvrsten sprach ### do er der herren willen | gehorte vnd sach ### got laz iv iwer erbe | immer saelich sin ### vnt ovch di lvete darinne | ia getvt div liebe wine min
###### 695 | ### des teiles wol ce rate | den ir ir woldet geben ### da si sol tragen chrone | vnt sol ich daz gelaeben ### si mvz werden richer | danne iemen lebendiger si ### swaz ir svs gebietet | des pin ich iv dienestlichen bi
###### 696 | ### do sprach div vrowe criemhilt | habt ir der erbe rat ### vmb bvrgende daegene | so liht ez niht en stat ### si mvg ein chvnich gerne | fvren in sin lant ### ia sol si mit mir teilen | miner liben brvoder hant
###### 697 | ### do sprach der herre gernot | nv nim dir swen dv wil ### di gerne mit dir ritent | der vindestv hi vil ### von drizech hvndert rechen | wir geben dir tvsent man ### di sin din heimgesinde | criemhilt do senden began
###### 698 | ### nach hagen von tronege | vnd ovch nach ortwin ### ob di vnt ovch ir mage | criemhilde wolden sin ### do gewan darvmbe hagene | ein zornlichez leben ### er sprach ia ne mach vns gvnther | ce werlde niemen gegeben
###### 699 | ### ander iwer gesinde | di lat iv volgen mite ### want ir doch wol bechennet | der tronegaere site ### wir mvoezen bi den chvnigen | hir en hove bestan ### wir svln in langer dienen | den wir alher gevolget han
###### 700 | ### daz liezen si beliben | do bereiten si sich dan ### ir edel ingesinde | vrov criemhilt zv zir gewan ### zw vnt drizech meide | vnt fvmpfhvndert man ### eckewart der grave | der volgete sifride dan
###### 701 | ### vrlovp si alle namen | beidiv ritter vnt chneht ### maegede vnd vrowen | daz was michel reht ### gescheiden chvssende | wurden si cehant ### si rvmten vroelichen | des kvnech gvntheres lant
###### 702 | ### do beleiten si ir mage | vil verre vf den wegen ### man hiez in allenthalben | ir nahtsaelde laegen ### swa si se gerne namen | al dvrch der chvnige lant ### do wurden botten balde | sigemvnde dan gesant
###### 703 | ### daz er daz wizen solde | vnt ovch sigelint ### daz sin svn chomen wolde | vnd ovch vrovn vten chint ### criemhilt div vil schone | von wormez vber rin ### do ne chvnden in div maere | nimmer lieber gesin
###### 704 | ### so wol mich sprach do sigmvnt | daz ich gelaebet han ### daz criemhilt div vil schone | sol hie gechronet gan ### des mvozen wol getiwert | sin al div erbe min ### min svn der edel sifrit | sol hie selbe chvenech sin
###### 705 | ### do gap div edele sigelint | vil manigen samit rot ### silber vnt golt vil swaere | daz was ir bottenbrot ### si vrevte sich der maere | div si do vernam ### sich chleidete ir ingesinde | mit vlize als in do wol gezam
###### 706 | ### man sagete wer da chome | mit im in daz lant ### do hiezen si gesidele | rihten sa cehant ### darzv er gecrhonet | vor vrivnden solde gan ### do ritten im engegene | des chvnich sigemvndes man
###### 707 | ### ist iemen baz enpfangen | daz ist mir vmbechant ### danne di helde maere | in sigemvndes lant ### sigelint div schone | criemhilt engegene reit ### mit maniger vrowen schonen | ir volgeten ritter gemeit
###### 708 | ### in einer tageweide | da man di geste sach ### di chvnden vnt di vremden | liden vngemach ### vnz daz si chomen | ceiner bvrge wit ### div was geheizen santen | da si chrone trvgen sit
###### 709 | ### mit lachendem mvnde | sigelint vnt sigmvnt ### chvsten criemhilt | dvrch liebe ce maniger stvnt ### vnt ovch sifrit | in was ir leit benomen ### allez ir gesinde | was in groze willechomen
###### 710 | ### man bat di geste bringen | fvr sigmvndes sal ### di schonen ivnchvrowen | di hvp man da ce tal ### nider von den moeren | da was vil manich man ### do man den schonen | vrowen mit vl vlize dienen began
###### 711 | ### swi groz ir hohzit | bi dem rine was bechant ### noch gap man den helden | hie vil bezer gewant ### denne si ie getrvgen | noch bi allen ir tagen ### man mohte michel | wunder von ir richeite sagen
###### 712 | ### do si in ir hohen eren | sazen vnd heten genvch ### waz goltvarwer geren | ir ingesinde trvch ### perln vnd edel gesteine | verwieret wol darin ### svs pflach ir vlizechlichen | sigelint div edel chvenegin
###### 713 | ### do sprach vor sinen vrivnden | der herre sigemvnt ### den sifrides magen | tvn ich allen chvnt ### er sol vor disen recken | di mine chrone tragen ### div maere horten gerne | di von niderlande sagen
###### 714 | ### er bevalch im sin | gerihte crone vnd ovch daz lant ### sit was er ir aller meister | di er ce rehte vant ### vnt dar er riten solde | daz wart also getan ### daz man sere vorhte | der shonen crimhilden man
###### 715 | ### in disen grozen eren | lebet er daz ist war ### vnd rihte vnder chrone | vnz an daz cehende iar ### daz div vil schone vrowe | einen svn gewan ### daz was des chvneges magen | nach ir willen ergan
###### 716 | ### den ilte man do tovffen | vnd gap im einen namen ### gvnther nach sinem oheim | des en dorft er sich niht schamen ### geriet er nach den magen | daz waer im wol ergan ### do zoh man in mit vlize | daz was von shvlden getan
###### 717 | ### in den selben ziten | starp vrov sigelint ### do het den gewalt mit alle | der edeln voten chint ### der so richen vrowen | ob landen wol gezam ### daz chlagten do genvge | ds si der tot von in genam
###### 718 | ### nv het ovch dort bi rine | so wir horen sagen ### bi gvnther dem richen | einen svn getragen ### prvnnhilt div schoene | in bvergvnden lant ### dvrch des heldes liebe | wart er sifrit genant
###### 719 | ### wi rehte vlizechlichen | sin man hveten hiez ### gvnther der edele | im magezogen liez ### di ez wol chvnden ziehen | ce einem biderbem man ### hey waz im vngelveche | sit der vrivnde an gewan
###### 720 | ### maere zallen ziten | der wart vil geseit ### wi rehte lobelichen | di recken vil gemeit ### lebten zallen stvnden | in sigemvndes lant ### alsam tet ovch gvnther | mit sinen magen vzerchant
###### 721 | ### daz lant cen nibelvngen | sifride diente hie ### richer siner mage | wart noch deheiner nie ### vnt ovch nibelvnges recken | vnt ir beder gvt ### des trvch der vil chvene | deste hoehern mvt
###### 722 | ### hort den allermeisten | den helt ie gewan ### ane di es e pflagen | haete nv der chvene man ### den er vor einem berge | mit siner hende erstreit ### darvmbe slvch er ce tode | vil manigen ritter gemeit
###### 723 | ### er heten wunsh der eren | vnt waere des niht geshehen ### so mvese man von schvlden | dem edeln rechen iehen ### daz er waere ein der beste | der vf oerss ie gasaz ### man vorhte sine sterche | vnt tet vil pilliche daz

<<< Übersicht <<< vorige Seite nächste Seite >>>